==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/alb/kotlin/inputs/ListenerRuleActionAuthenticateCognitoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.alb.kotlin.inputs

import com.pulumi.aws.alb.inputs.ListenerRuleActionAuthenticateCognitoArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 *
 * @property authenticationRequestExtraParams The query parameters to include in the redirect request to the authorization endpoint. Max: 10.
 * @property onUnauthenticatedRequest The behavior if the user is not authenticated. Valid values: `deny`, `allow` and `authenticate`
 * @property scope The set of user claims to be requested from the IdP.
 * @property sessionCookieName The name of the cookie used to maintain session information.
 * @property sessionTimeout The maximum duration of the authentication session, in seconds.
 * @property userPoolArn The ARN of the Cognito user pool.
 * @property userPoolClientId The ID of the Cognito user pool client.
 * @property userPoolDomain The domain prefix or fully-qualified domain name of the Cognito user pool.
 */
public data class ListenerRuleActionAuthenticateCognitoArgs(
    public val authenticationRequestExtraParams: Output<Map<String, String>>? = null,
    public val onUnauthenticatedRequest: Output<String>? = null,
    public val scope: Output<String>? = null,
    public val sessionCookieName: Output<String>? = null,
    public val sessionTimeout: Output<Int>? = null,
    public val userPoolArn: Output<String>,
    public val userPoolClientId: Output<String>,
    public val userPoolDomain: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.alb.inputs.ListenerRuleActionAuthenticateCognitoArgs> {
    override fun toJava(): com.pulumi.aws.alb.inputs.ListenerRuleActionAuthenticateCognitoArgs =
        com.pulumi.aws.alb.inputs.ListenerRuleActionAuthenticateCognitoArgs.builder()
            .authenticationRequestExtraParams(
                authenticationRequestExtraParams?.applyValue({ args0 ->
                    args0.map({ args0 -> args0.key.to(args0.value) }).toMap()
                }),
            )
            .onUnauthenticatedRequest(onUnauthenticatedRequest?.applyValue({ args0 -> args0 }))
            .scope(scope?.applyValue({ args0 -> args0 }))
            .sessionCookieName(sessionCookieName?.applyValue({ args0 -> args0 }))
            .sessionTimeout(sessionTimeout?.applyValue({ args0 -> args0 }))
            .userPoolArn(userPoolArn.applyValue({ args0 -> args0 }))
            .userPoolClientId(userPoolClientId.applyValue({ args0 -> args0 }))
            .userPoolDomain(userPoolDomain.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ListenerRuleActionAuthenticateCognitoArgs].
 */
@PulumiTagMarker
public class ListenerRuleActionAuthenticateCognitoArgsBuilder internal constructor() {
    private var authenticationRequestExtraParams: Output<Map<String, String>>? = null

    private var onUnauthenticatedRequest: Output<String>? = null

    private var scope: Output<String>? = null

    private var sessionCookieName: Output<String>? = null

    private var sessionTimeout: Output<Int>? = null

    private var userPoolArn: Output<String>? = null

    private var userPoolClientId: Output<String>? = null

    private var userPoolDomain: Output<String>? = null

    /**
     * @param value The query parameters to include in the redirect request to the authorization endpoint. Max: 10.
     */
    @JvmName("orutghxsreuqxjjq")
    public suspend fun authenticationRequestExtraParams(`value`: Output<Map<String, String>>) {
        this.authenticationRequestExtraParams = value
    }

    /**
     * @param value The behavior if the user is not authenticated. Valid values: `deny`, `allow` and `authenticate`
     */
    @JvmName("ibxjcpwprtgapviy")
    public suspend fun onUnauthenticatedRequest(`value`: Output<String>) {
        this.onUnauthenticatedRequest = value
    }

    /**
     * @param value The set of user claims to be requested from the IdP.
     */
    @JvmName("fopwhlwxppcjcldu")
    public suspend fun scope(`value`: Output<String>) {
        this.scope = value
    }

    /**
     * @param value The name of the cookie used to maintain session information.
     */
    @JvmName("roxsiprohhhrnuel")
    public suspend fun sessionCookieName(`value`: Output<String>) {
        this.sessionCookieName = value
    }

    /**
     * @param value The maximum duration of the authentication session, in seconds.
     */
    @JvmName("iouaudjjscthxyat")
    public suspend fun sessionTimeout(`value`: Output<Int>) {
        this.sessionTimeout = value
    }

    /**
     * @param value The ARN of the Cognito user pool.
     */
    @JvmName("houjvnngbsciegqe")
    public suspend fun userPoolArn(`value`: Output<String>) {
        this.userPoolArn = value
    }

    /**
     * @param value The ID of the Cognito user pool client.
     */
    @JvmName("mdmshtxmftyirvwg")
    public suspend fun userPoolClientId(`value`: Output<String>) {
        this.userPoolClientId = value
    }

    /**
     * @param value The domain prefix or fully-qualified domain name of the Cognito user pool.
     */
    @JvmName("wjntyokqvdenbhww")
    public suspend fun userPoolDomain(`value`: Output<String>) {
        this.userPoolDomain = value
    }

    /**
     * @param value The query parameters to include in the redirect request to the authorization endpoint. Max: 10.
     */
    @JvmName("prxociltgordfywd")
    public suspend fun authenticationRequestExtraParams(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.authenticationRequestExtraParams = mapped
    }

    /**
     * @param values The query parameters to include in the redirect request to the authorization endpoint. Max: 10.
     */
    @JvmName("mujatovdswnrxmvw")
    public fun authenticationRequestExtraParams(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.authenticationRequestExtraParams = mapped
    }

    /**
     * @param value The behavior if the user is not authenticated. Valid values: `deny`, `allow` and `authenticate`
     */
    @JvmName("srvbtgovdwqumgsu")
    public suspend fun onUnauthenticatedRequest(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.onUnauthenticatedRequest = mapped
    }

    /**
     * @param value The set of user claims to be requested from the IdP.
     */
    @JvmName("drtlkdymuorvsaun")
    public suspend fun scope(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scope = mapped
    }

    /**
     * @param value The name of the cookie used to maintain session information.
     */
    @JvmName("ioennrqcthnbytsd")
    public suspend fun sessionCookieName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sessionCookieName = mapped
    }

    /**
     * @param value The maximum duration of the authentication session, in seconds.
     */
    @JvmName("jjovnyuwngcmghlt")
    public suspend fun sessionTimeout(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sessionTimeout = mapped
    }

    /**
     * @param value The ARN of the Cognito user pool.
     */
    @JvmName("enfgudboachueiyi")
    public suspend fun userPoolArn(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.userPoolArn = mapped
    }

    /**
     * @param value The ID of the Cognito user pool client.
     */
    @JvmName("mlgagqajntvxgpkx")
    public suspend fun userPoolClientId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.userPoolClientId = mapped
    }

    /**
     * @param value The domain prefix or fully-qualified domain name of the Cognito user pool.
     */
    @JvmName("wbdtlbnrmshmbuey")
    public suspend fun userPoolDomain(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.userPoolDomain = mapped
    }

    internal fun build(): ListenerRuleActionAuthenticateCognitoArgs =
        ListenerRuleActionAuthenticateCognitoArgs(
            authenticationRequestExtraParams = authenticationRequestExtraParams,
            onUnauthenticatedRequest = onUnauthenticatedRequest,
            scope = scope,
            sessionCookieName = sessionCookieName,
            sessionTimeout = sessionTimeout,
            userPoolArn = userPoolArn ?: throw PulumiNullFieldException("userPoolArn"),
            userPoolClientId = userPoolClientId ?: throw PulumiNullFieldException("userPoolClientId"),
            userPoolDomain = userPoolDomain ?: throw PulumiNullFieldException("userPoolDomain"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/alb/kotlin/inputs/ListenerRuleActionAuthenticateCognitoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.alb.kotlin.inputs

import com.pulumi.aws.alb.inputs.ListenerRuleActionAuthenticateCognitoArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 *
 * @property authenticationRequestExtraParams The query parameters to include in the redirect request to the authorization endpoint. Max: 10.
 * @property onUnauthenticatedRequest The behavior if the user is not authenticated. Valid values: `deny`, `allow` and `authenticate`
 * @property scope The set of user claims to be requested from the IdP.
 * @property sessionCookieName The name of the cookie used to maintain session information.
 * @property sessionTimeout The maximum duration of the authentication session, in seconds.
 * @property userPoolArn The ARN of the Cognito user pool.
 * @property userPoolClientId The ID of the Cognito user pool client.
 * @property userPoolDomain The domain prefix or fully-qualified domain name of the Cognito user pool.
 */
public data class ListenerRuleActionAuthenticateCognitoArgs(
    public val authenticationRequestExtraParams: Output<Map<String, String>>? = null,
    public val onUnauthenticatedRequest: Output<String>? = null,
    public val scope: Output<String>? = null,
    public val sessionCookieName: Output<String>? = null,
    public val sessionTimeout: Output<Int>? = null,
    public val userPoolArn: Output<String>,
    public val userPoolClientId: Output<String>,
    public val userPoolDomain: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.alb.inputs.ListenerRuleActionAuthenticateCognitoArgs> {
    override fun toJava(): com.pulumi.aws.alb.inputs.ListenerRuleActionAuthenticateCognitoArgs =
        com.pulumi.aws.alb.inputs.ListenerRuleActionAuthenticateCognitoArgs.builder()
            .authenticationRequestExtraParams(
                authenticationRequestExtraParams?.applyValue({ args0 ->
                    args0.map({ args0 -> args0.key.to(args0.value) }).toMap()
                }),
            )
            .onUnauthenticatedRequest(onUnauthenticatedRequest?.applyValue({ args0 -> args0 }))
            .scope(scope?.applyValue({ args0 -> args0 }))
            .sessionCookieName(sessionCookieName?.applyValue({ args0 -> args0 }))
            .sessionTimeout(sessionTimeout?.applyValue({ args0 -> args0 }))
            .userPoolArn(userPoolArn.applyValue({ args0 -> args0 }))
            .userPoolClientId(userPoolClientId.applyValue({ args0 -> args0 }))
            .userPoolDomain(userPoolDomain.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ListenerRuleActionAuthenticateCognitoArgs].
 */
@PulumiTagMarker
public class ListenerRuleActionAuthenticateCognitoArgsBuilder internal constructor() {
    private var authenticationRequestExtraParams: Output<Map<String, String>>? = null

    private var onUnauthenticatedRequest: Output<String>? = null

    private var scope: Output<String>? = null

    private var sessionCookieName: Output<String>? = null

    private var sessionTimeout: Output<Int>? = null

    private var userPoolArn: Output<String>? = null

    private var userPoolClientId: Output<String>? = null

    private var userPoolDomain: Output<String>? = null

    /**
     * @param value The query parameters to include in the redirect request to the authorization endpoint. Max: 10.
     */
    @JvmName("cysmnbqjquetnksf")
    public suspend fun authenticationRequestExtraParams(`value`: Output<Map<String, String>>) {
        this.authenticationRequestExtraParams = value
    }

    /**
     * @param value The behavior if the user is not authenticated. Valid values: `deny`, `allow` and `authenticate`
     */
    @JvmName("dxcrysmonndrxdrp")
    public suspend fun onUnauthenticatedRequest(`value`: Output<String>) {
        this.onUnauthenticatedRequest = value
    }

    /**
     * @param value The set of user claims to be requested from the IdP.
     */
    @JvmName("gjlhdrblxnhixhph")
    public suspend fun scope(`value`: Output<String>) {
        this.scope = value
    }

    /**
     * @param value The name of the cookie used to maintain session information.
     */
    @JvmName("stbbqlykvcrysseq")
    public suspend fun sessionCookieName(`value`: Output<String>) {
        this.sessionCookieName = value
    }

    /**
     * @param value The maximum duration of the authentication session, in seconds.
     */
    @JvmName("rnlsyswemsxgbjwr")
    public suspend fun sessionTimeout(`value`: Output<Int>) {
        this.sessionTimeout = value
    }

    /**
     * @param value The ARN of the Cognito user pool.
     */
    @JvmName("oeclqiteldjmpqjj")
    public suspend fun userPoolArn(`value`: Output<String>) {
        this.userPoolArn = value
    }

    /**
     * @param value The ID of the Cognito user pool client.
     */
    @JvmName("bndqtlbfikjnovgq")
    public suspend fun userPoolClientId(`value`: Output<String>) {
        this.userPoolClientId = value
    }

    /**
     * @param value The domain prefix or fully-qualified domain name of the Cognito user pool.
     */
    @JvmName("yfqnkeojgmhsoatw")
    public suspend fun userPoolDomain(`value`: Output<String>) {
        this.userPoolDomain = value
    }

    /**
     * @param value The query parameters to include in the redirect request to the authorization endpoint. Max: 10.
     */
    @JvmName("wcwfvcyvcokelmgy")
    public suspend fun authenticationRequestExtraParams(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.authenticationRequestExtraParams = mapped
    }

    /**
     * @param values The query parameters to include in the redirect request to the authorization endpoint. Max: 10.
     */
    @JvmName("kuyuawxjmyalwetf")
    public fun authenticationRequestExtraParams(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.authenticationRequestExtraParams = mapped
    }

    /**
     * @param value The behavior if the user is not authenticated. Valid values: `deny`, `allow` and `authenticate`
     */
    @JvmName("mxabrarernoscjvu")
    public suspend fun onUnauthenticatedRequest(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.onUnauthenticatedRequest = mapped
    }

    /**
     * @param value The set of user claims to be requested from the IdP.
     */
    @JvmName("ciabiocqrumwjxkh")
    public suspend fun scope(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scope = mapped
    }

    /**
     * @param value The name of the cookie used to maintain session information.
     */
    @JvmName("iahhbhmkbnwpapfs")
    public suspend fun sessionCookieName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sessionCookieName = mapped
    }

    /**
     * @param value The maximum duration of the authentication session, in seconds.
     */
    @JvmName("kqpbkphcvdyqaekf")
    public suspend fun sessionTimeout(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sessionTimeout = mapped
    }

    /**
     * @param value The ARN of the Cognito user pool.
     */
    @JvmName("rttiwylkexshqaji")
    public suspend fun userPoolArn(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.userPoolArn = mapped
    }

    /**
     * @param value The ID of the Cognito user pool client.
     */
    @JvmName("yvsurasiemseockj")
    public suspend fun userPoolClientId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.userPoolClientId = mapped
    }

    /**
     * @param value The domain prefix or fully-qualified domain name of the Cognito user pool.
     */
    @JvmName("tpjkjfwdeghqvqfn")
    public suspend fun userPoolDomain(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.userPoolDomain = mapped
    }

    internal fun build(): ListenerRuleActionAuthenticateCognitoArgs =
        ListenerRuleActionAuthenticateCognitoArgs(
            authenticationRequestExtraParams = authenticationRequestExtraParams,
            onUnauthenticatedRequest = onUnauthenticatedRequest,
            scope = scope,
            sessionCookieName = sessionCookieName,
            sessionTimeout = sessionTimeout,
            userPoolArn = userPoolArn ?: throw PulumiNullFieldException("userPoolArn"),
            userPoolClientId = userPoolClientId ?: throw PulumiNullFieldException("userPoolClientId"),
            userPoolDomain = userPoolDomain ?: throw PulumiNullFieldException("userPoolDomain"),
        )
}
